==> libignition-common3-3.3.0-h21ff451_0.tar.bz2: Library/lib/cmake/ignition-common3-all/ignition-common3-all-config.cmake <==
# - Config to retrieve all components of the ignition-common3 package
#
# This should only be invoked by ignition-common3-config.cmake.
#
# To retrieve this meta-package, use:
# find_package(ignition-common3 COMPONENTS all)
#
# This creates the target ignition-common3::all which will link to all known
# components of ignition-common3, including the core library.
#
# This also creates the variable ignition-common3_ALL_LIBRARIES
#
################################################################################

cmake_minimum_required(VERSION 3.10.2 FATAL_ERROR)

if(ignition-common3_ALL_CONFIG_INCLUDED)
  return()
endif()
set(ignition-common3_ALL_CONFIG_INCLUDED TRUE)

if(NOT ignition-common3-all_FIND_QUIETLY)
  message(STATUS "Looking for all libraries of ignition-common3 -- found version 3.3.0")
endif()


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was ignition-all-config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# Get access to the find_dependency utility
include(CMakeFindDependencyMacro)

# Find the core library
find_dependency(ignition-common3 3.3.0 EXACT)

# Find the component libraries
find_dependency(ignition-common3-events 3.3.0 EXACT)
find_dependency(ignition-common3-profiler 3.3.0 EXACT)

if(NOT TARGET ignition-common3::ignition-common3-all)
  include("${CMAKE_CURRENT_LIST_DIR}/ignition-common3-all-targets.cmake")

  add_library(ignition-common3::all INTERFACE IMPORTED)
  set_target_properties(ignition-common3::all PROPERTIES
    INTERFACE_LINK_LIBRARIES "ignition-common3::ignition-common3-all")

endif()

# Create the "requested" target if it does not already exist
if(NOT TARGET ignition-common3::requested)
  add_library(ignition-common3::requested INTERFACE IMPORTED)
endif()

# Link the "all" target to the "requested" target
get_target_property(ign_requested_components ignition-common3::requested INTERFACE_LINK_LIBRARIES)
if(NOT ign_requested_components)
  set_target_properties(ignition-common3::requested PROPERTIES
    INTERFACE_LINK_LIBRARIES "ignition-common3::ignition-common3-all")
else()
  set_target_properties(ignition-common3::requested PROPERTIES
    INTERFACE_LINK_LIBRARIES "${ign_requested_components};ignition-common3::ignition-common3-all")
endif()

set(ignition-common3_ALL_LIBRARIES ignition-common3::ignition-common3-all)

==> libignition-common3-3.4.0-h21ff451_2.tar.bz2: Library/lib/cmake/ignition-common3-all/ignition-common3-all-config.cmake <==
# - Config to retrieve all components of the ignition-common3 package
#
# This should only be invoked by ignition-common3-config.cmake.
#
# To retrieve this meta-package, use:
# find_package(ignition-common3 COMPONENTS all)
#
# This creates the target ignition-common3::all which will link to all known
# components of ignition-common3, including the core library.
#
# This also creates the variable ignition-common3_ALL_LIBRARIES
#
################################################################################

cmake_minimum_required(VERSION 3.10.2 FATAL_ERROR)

if(ignition-common3_ALL_CONFIG_INCLUDED)
  return()
endif()
set(ignition-common3_ALL_CONFIG_INCLUDED TRUE)

if(NOT ignition-common3-all_FIND_QUIETLY)
  message(STATUS "Looking for all libraries of ignition-common3 -- found version 3.4.0")
endif()


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was ignition-all-config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# Get access to the find_dependency utility
include(CMakeFindDependencyMacro)

# Find the core library
find_dependency(ignition-common3 3.4.0 EXACT)

# Find the component libraries
find_dependency(ignition-common3-events 3.4.0 EXACT)
find_dependency(ignition-common3-graphics 3.4.0 EXACT)
find_dependency(ignition-common3-profiler 3.4.0 EXACT)

if(NOT TARGET ignition-common3::ignition-common3-all)
  include("${CMAKE_CURRENT_LIST_DIR}/ignition-common3-all-targets.cmake")

  add_library(ignition-common3::all INTERFACE IMPORTED)
  set_target_properties(ignition-common3::all PROPERTIES
    INTERFACE_LINK_LIBRARIES "ignition-common3::ignition-common3-all")

endif()

# Create the "requested" target if it does not already exist
if(NOT TARGET ignition-common3::requested)
  add_library(ignition-common3::requested INTERFACE IMPORTED)
endif()

# Link the "all" target to the "requested" target
get_target_property(ign_requested_components ignition-common3::requested INTERFACE_LINK_LIBRARIES)
if(NOT ign_requested_components)
  set_target_properties(ignition-common3::requested PROPERTIES
    INTERFACE_LINK_LIBRARIES "ignition-common3::ignition-common3-all")
else()
  set_target_properties(ignition-common3::requested PROPERTIES
    INTERFACE_LINK_LIBRARIES "${ign_requested_components};ignition-common3::ignition-common3-all")
endif()

set(ignition-common3_ALL_LIBRARIES ignition-common3::ignition-common3-all)
